==> de-BBBike-3.16_1.tbz: BBBike/Bundle/BBBike.pm <==
# -*- perl -*-

package Bundle::BBBike;

$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);

1;

__END__

=head1 NAME

Bundle::BBBike - A bundle to install all dependencies of BBBike

=head1 SYNOPSIS

 perl -I`pwd` -MCPAN -e 'install Bundle::BBBike'

=head1 CONTENTS


Tk 800.000	- das absolute Muss!

Tk::FireButton	- "Firebutton"-Funktionalitt fr die Windrose

Tk::Pod 2.8	- Online-Hilfe

Tk::FontDialog	- zum ndern des Zeichensatzes aus dem Programm heraus

Tk::JPEG

Tie::Watch

Tk::HistEntry

Tk::Stderr	- optionales Redirect von Fehlermeldungen in ein Tk-Fenster

Tk::DateEntry 1.38

Tk::Date

Tk::PNG	- Fr Icons mit besserer Alpha-Untersttzung

Tk::NumEntry 2.06

X11::Protocol	- Rotated text support

LWP::UserAgent	- fr die WWW-Verbindungen (z.B. Wetterbericht); in der Perl/Tk-GUI empfohlen fr Daten-Updates ber das Internet (ansonsten wird Http.pm verwendet)

Image::Magick	- fr Bildmanipulationen beim Radar-Bild der FU

Apache::Session::DB_File	- optionale Session-Verwaltung fr das CGI-Programm, notwendig fr wapbbbike

Apache::Session::Counted	- optionale aber sehr zu empfehlende Session-Verwaltung fr das CGI-Programm

XML::SAX	- CPAN.pm kann XML::SAX nicht ber XML::Simple automatisch installieren

XML::Simple	- optional fr XML-Dumps der BBBike-Route

XML::Parser	- optional fr UAProf parsing (alternative wre XML::SAX::PurePerl)

XML::LibXML	- optional fr das Parsen und Erzeugen von GPX-Dateien

XML::Twig	- alternativ fr das Parsen und Erzeugen von GPX-Dateien, bentigt XML::Parser

YAML	- optional fr YAML-Dumps der BBBike-Route sowie fuer temp_blockings

Mail::Mailer 1.53	- falls man aus bbbike heraus E-Mails mit der Routenbeschreibung verschicken will

MIME::Lite	- Versenden von Benutzer-Kommentaren im Webinterface

String::Approx 2.7	- oder man verwendet agrep (mindestens Version 3.0)

String::Similarity	- optional fr den temp_blockings-Editor und ungenaue Suche in der Perl/Tk-Applikation

Storable	- fr das Caching beim CGI-Programm

MLDBM

GD 1.18	- zum On-the-fly-Erzeugen von Grafiken beim CGI-Programm

Chart::ThreeD::Pie	- Tortendiagramme in der Statistik

Algorithm::Permute 0.08	- Fr das Problem des Handlungsreisenden (schnellerer Permutor)

List::Permutor	- Fr das Problem des Handlungsreisenden (langsamerer Permutor)

PDF::Image::GIFImage	- Erzeugung der Route als PDF-Dokument --- das ist die neueste Version wie auf sourceforge erhltlich! (http://prdownloads.sourceforge.net/perl-pdf/perl-pdf-0.06.1b.tar.gz?download oder direkt: http://heanet.dl.sourceforge.net/sourceforge/perl-pdf/perl-pdf-0.06.1b.tar.gz)

Font::Metrics::Helvetica	- Fr die Reparatur der Zeichenbreitentabellen in PDF::Create

BSD::Resource

Devel::Peek

Statistics::Descriptive

Math::MatrixReal

Class::Accessor	- fr GPS::GpsmanData, die ESRI-Module etc.

Template	- fr BBBikeDraw::MapServer

Inline::C	- fr den schnelleren Suchalgorithmus, siehe ext/Strassen-Inline

Pod::Usage	- fr das Ausgeben der 'Usage' in einigen Entwicklungs-Tools

Palm::PalmDoc	- fr das Erzeugen von palmdoc-Dateien mit der Routenbeschreibung

Astro::Sunrise 0.85	- Anzeige des Sonnenuntergangs/-aufgangs im Info-Fenster

WWW::Shorten	- Krzen der langen Mapserver-Links im Info-Fenster

File::ReadBackwards	- LogTracker plugin, Edititeren

Date::Pcalc	- LogTracker plugin (mgliche Alternative ist Date::Calc)

XBase	- Erzeugen der Mapserver- oder anderer ESRI-Dateien

IPC::Run	- hilft bei der sicheren Ausfhrung von externen Kommandos (insbesondere fr Win32)

Imager	- additional optional BBBikeDraw backend for PNG graphics

Image::ExifTool	- fr geocode_images

SVG	- additional optional BBBikeDraw backend for SVG graphics

Object::Iterate	- Notwendig fr die bbd2-esri-Konvertierung

Object::Realize::Later	- Notwendig fr Strassen::Lazy, selten bentigt

Archive::Zip	- Zum Zippen der BBBike-Daten in bbbike-data.cgi

Text::CSV_XS	- Fr das Parsen des MapInfo-Formats

DBI	- Fr XBase/MySQL, siehe unten

DBD::XBase	- Fr das Parsen des ESRI-Shapefile-Formats

XBase	- Ebenfalls fr das Parsen des ESRI-Shapefile-Formats

DBD::mysql	- Fr den Zugriff auf die Hausnummerdatenbank

Tie::IxHash	- Damit Direktiven in Straen-Daten geordnet bleiben

CDB_File	- Fr die alternative A*-Optimierung in XS/C

DB_File::Lock	- Same DB_File operations, used in Strassen::Index

GPS::Garmin	- fr GPS-Upload

Geo::SpaceManager 0.91	- Intelligentere Labelplatzierung, bei der PDF-Ausgabe verwendet

Tk::ExecuteCommand	- Bessere Fehlerberichte im temp_blockings-Editor

Algorithm::Diff	- Unterschiede im temp_blockings-Editor anzeigen

Sort::Naturally	- Fr natrliches Sortieren von bbd-Dateien

WWW::Search::Google	- Suche in luise-berlin

Geo::Coder::Google	- Geocoding ber Googlemaps

Geo::Coder::Yahoo	- Geocoding ber Yahoo

Image::Info

Test::More

Test::Differences

Test::NoWarnings

WWW::Mechanize	- Fr Testen des CGI-Interfaces

Devel::Leak	- Fr Memory-Leak-Tests

Text::Table


=head1 DESCRIPTION

Dieses BE<uuml>ndel listet alle erforderlichen und empfohlenen Module
fE<uuml>r BBBike auf. Bis auf B<Tk> sind alle anderen Module optional.

This bundle lists all required and optional perl modules for BBBike.
Only B<Tk> is really required, all other modules are optional.

=head1 AUTHOR

Slaven Rezic <slaven@rezic.de>

=cut

==> de-BBBike-3.17_1.tbz: BBBike/Bundle/BBBike.pm <==
# -*- perl -*-

package Bundle::BBBike;

$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);

1;

__END__

=head1 NAME

Bundle::BBBike - A bundle to install all dependencies of BBBike

=head1 SYNOPSIS

 perl -I`pwd` -MCPAN -e 'install Bundle::BBBike'

=head1 CONTENTS


Tk 800.000	- das absolute Muss!

Tk::FireButton	- "Firebutton"-Funktionalitt fr die Windrose

Tk::Pod 2.8	- Online-Hilfe

Tk::FontDialog	- zum ndern des Zeichensatzes aus dem Programm heraus

Tk::JPEG

Tie::Watch

Tk::HistEntry

Tk::Stderr	- optionales Redirect von Fehlermeldungen in ein Tk-Fenster

Tk::DateEntry 1.38

Tk::Date

Tk::PNG	- Fr Icons mit besserer Alpha-Untersttzung

Tk::NumEntry 2.06

X11::Protocol	- Rotated text support

LWP::UserAgent	- fr die WWW-Verbindungen (z.B. Wetterbericht); in der Perl/Tk-GUI empfohlen fr Daten-Updates ber das Internet (ansonsten wird Http.pm verwendet)

Image::Magick	- fr Bildmanipulationen beim Radar-Bild der FU

Apache::Session::DB_File	- optionale Session-Verwaltung fr das CGI-Programm, notwendig fr wapbbbike

Apache::Session::Counted	- optionale aber sehr zu empfehlende Session-Verwaltung fr das CGI-Programm

XML::SAX	- CPAN.pm kann XML::SAX nicht ber XML::Simple automatisch installieren

XML::Simple	- optional fr XML-Dumps der BBBike-Route

XML::LibXML	- optional fr das Parsen und Erzeugen von GPX-Dateien und fr UAProf parsing

XML::Parser	- optional fr UAProf parsing (bevorzugt wird allerdings XML::LibXML::SAX oder XML::SAX::PurePerl)

XML::Twig	- alternativ fr das Parsen und Erzeugen von GPX-Dateien, bentigt XML::Parser

YAML	- optional fr YAML-Dumps der BBBike-Route sowie fuer temp_blockings

YAML::Syck	- optional fr die Testsuite, knnte auch YAML.pm in Zukunft ersetzen

JSON::XS	- optional fr diverse Serialisierungsaufgaben

Mail::Mailer 1.53	- falls man aus bbbike heraus E-Mails mit der Routenbeschreibung verschicken will

MIME::Lite	- Versenden von Benutzer-Kommentaren im Webinterface

String::Approx 2.7	- oder man verwendet agrep (mindestens Version 3.0)

String::Similarity	- optional fr den temp_blockings-Editor und ungenaue Suche in der Perl/Tk-Applikation

Storable	- fr das Caching beim CGI-Programm

MLDBM

GD 1.18	- zum On-the-fly-Erzeugen von Grafiken beim CGI-Programm

Chart::ThreeD::Pie	- Tortendiagramme in der Statistik

Algorithm::Permute 0.08	- Fr das Problem des Handlungsreisenden (schnellerer Permutor)

List::Permutor	- Fr das Problem des Handlungsreisenden (langsamerer Permutor)

PDF::Create 0.06	- Erzeugung der Route als PDF-Dokument

Font::Metrics::Helvetica	- Fr die Reparatur der Zeichenbreitentabellen in PDF::Create

BSD::Resource

Devel::Peek

Statistics::Descriptive

Math::MatrixReal

Class::Accessor	- fr die ESRI-Module etc.

Template	- fr BBBikeDraw::MapServer

Inline::C	- fr den schnelleren Suchalgorithmus, siehe ext/Strassen-Inline

Pod::Usage	- fr das Ausgeben der 'Usage' in einigen Entwicklungs-Tools

Palm::PalmDoc	- fr das Erzeugen von palmdoc-Dateien mit der Routenbeschreibung

Astro::Sunrise 0.85	- Anzeige des Sonnenuntergangs/-aufgangs im Info-Fenster

WWW::Shorten	- Krzen der langen Mapserver-Links im Info-Fenster

File::ReadBackwards	- LogTracker plugin, Edititeren

Date::Pcalc	- LogTracker plugin (mgliche Alternative ist Date::Calc)

XBase	- Erzeugen der Mapserver- oder anderer ESRI-Dateien

IPC::Run	- hilft bei der sicheren Ausfhrung von externen Kommandos (insbesondere fr Win32)

Imager	- additional optional BBBikeDraw backend for PNG graphics

Imager::Screenshot	- better screenshot module

Image::ExifTool	- fr geocode_images

SVG	- additional optional BBBikeDraw backend for SVG graphics

GD::SVG 0.31	- another SVG alternative, not used yet in production

Object::Iterate	- Notwendig fr die bbd2-esri-Konvertierung

Object::Realize::Later	- Notwendig fr Strassen::Lazy, selten bentigt

Archive::Zip	- Zum Zippen der BBBike-Daten in bbbike-data.cgi

Text::CSV_XS	- Fr das Parsen des MapInfo-Formats

DBI	- Fr XBase/MySQL, siehe unten

DBD::XBase	- Fr das Parsen des ESRI-Shapefile-Formats

XBase	- Ebenfalls fr das Parsen des ESRI-Shapefile-Formats

DBD::mysql	- Fr den Zugriff auf die Hausnummerdatenbank

Tie::IxHash	- Damit Direktiven in Straen-Daten geordnet bleiben

CDB_File	- Fr die alternative A*-Optimierung in XS/C

DB_File::Lock	- Same DB_File operations, used in Strassen::Index

GPS::Garmin	- fr GPS-Upload

Geo::SpaceManager 0.91	- Intelligentere Labelplatzierung, bei der PDF-Ausgabe verwendet

Geo::Distance::XS	- Berechnung von Entfernungen fr polare Koordinaten, mglicherweise schneller als Math::Trig

Geo::Distance 0.16	- Prereq fr Geo::Distance::XS

Geo::METAR	- Wetterdaten im METAR-Format

Tk::ExecuteCommand	- Bessere Fehlerberichte im temp_blockings-Editor

Algorithm::Diff	- Unterschiede im temp_blockings-Editor anzeigen

Sort::Naturally	- Fr natrliches Sortieren von bbd-Dateien

Yahoo::Search	- Suche in luise-berlin

Geo::Coder::Google 0.06	- Geocoding ber Googlemaps

Geo::Coder::Yahoo	- Geocoding ber Yahoo

Geo::Coder::Bing	- Geocoding ber Bing

Geo::Cloudmade	- Geocoding ber Cloudmade

Image::Info 1.29

Test::More

Test::Differences

WWW::Mechanize	- Fr Testen des CGI-Interfaces

WWW::Mechanize::FormFiller	- Fr Testen des CGI-Interfaces

Devel::Leak	- Fr Memory-Leak-Tests

Text::Table

Text::Unidecode	- Fr das Neu-Erzeugen der .bbd-Dateien in data

Data::Compare	- Fr das Neu-Erzeugen der .bbd-Dateien in data


=head1 DESCRIPTION

Dieses BE<uuml>ndel listet alle erforderlichen und empfohlenen Module
fE<uuml>r BBBike auf. Bis auf B<Tk> sind alle anderen Module optional.

This bundle lists all required and optional perl modules for BBBike.
Only B<Tk> is really required, all other modules are optional.

=head1 AUTHOR

Slaven Rezic <slaven@rezic.de>

=cut
